# The replication package for the paper "Automating Dependency Updates in Practice: An Exploratory Study on GitHub Dependabot"

This is the replication package for the paper "Automating Dependency Updates in Practice: An Exploratory Study on GitHub Dependabot". The paper is available on [arXiv](https://to.be.filled.on.camera.ready).

## Paper Abstract

Dependency management bots automatically open pull requests to update software dependencies on behalf of developers. Early research shows that developers are suspicious of updates performed by dependency management bots and feel tired of overwhelming notifications from these bots. Despite this, dependency management bots are becoming increasingly popular. Such contrast motivates us to investigate Dependabot, currently the most visible bot on GitHub, to reveal the effectiveness and limitations of state-of-art dependency management bots. We use exploratory data analysis and a developer survey to evaluate the effectiveness of Dependabot in keeping dependencies up-to-date, interacting with developers, reducing update suspicion, and reducing notification fatigue. We obtain mixed findings. On the positive side, Dependabot is effective in reducing technical lag and developers are highly receptive to its pull requests. On the negative side, its compatibility scores are too scarce to be effective in reducing update suspicion; developers tend to configure Dependabot toward reducing the number of notifications; and 11.3% of projects have deprecated Dependabot in favor of other alternatives. The survey confirms our findings and provides insights about the key missing features of Dependabot. Based on our findings, we derive and summarize the key characteristics of an ideal dependency management bot which can be grouped into four dimensions: configurability, autonomy, transparency, and self-adaptability.

## Replication Package Setup

We recommend using `virtualenv` to create a Python virtual environment for the replication package. The following commands create a virtual environment named `venv` and install the required Python packages.

```bash
python3 -m venv venv
source venv/bin/activate
pip install -r requirements.txt
```

After installing the required Python packages, you can run the following command to start the Jupyter notebook server.

```bash
jupyter notebook
```

## Replication Package Structure

The replication package is structured as follows:

- `data`: contains the raw data (in csv) required to replicate the results. 
- `plot`: contains the images in the paper.
- `utils`: utility scripts for calculating the inter-rater agreement and plotting.
- `rq*_*.ipynb`: these jupyter notebooks freeze the code and results of our experiments.